@@ -30,7 +30,7 @@ use vars qw( $obsolete_keymaps );
 sub guess_arch {
   my ($defs) = @_;
 
-  my $arch = `dpkg --print-installation-architecture`;
+  my $arch = `dpkg --print-architecture`;
   chomp $arch;
 
   # Overrides for testing:
